@ rem -  Library:       WebSphere MQ
@ rem -  Component:     WMQ SOAP Sample Programs
@ rem -  Part:          SecondAxis.java
@ rem - 
@ rem -   <START_COPYRIGHT> 
@ rem -   Licensed Materials - Property of IBM 
@ rem -                    
@ rem -   5724-B41         
@ rem -   (C) Copyright IBM Corp. 1994, 2003 All Rights Reserved. 
@ rem -                    
@ rem -   US Government Users Restricted Rights - Use, duplication or 
@ rem -   disclosure restricted by GSA ADP Schedule Contract with 
@ rem -   IBM Corp.        
@ rem -   <END_COPYRIGHT>
@ rem - setup classpath and path as required for WMQSoap
@ rem - make sure we are working in our own directory
@ rem - and get MA0R_HOME as an absolute paths usbale from anywhere
@ rem - but without the .. noise
@rem - demonstration of deploying and using new classes
@echo -
@echo ------------------------------------------------------------------------
@echo -
@echo - %0 [nopause]
@echo -
@echo This sample walks through the steps of creating, deploying and testing a new Java service
@echo to be called using the WebSphere MQ Transport for SOAP.
@echo -
@echo Unless nopause is specified, it will pause at each step.
@echo -
@echo This uses a 'bottom up' technique, starting with the Java service,
@echo and moving up through wsdl and proxy generation to coding a client.
@echo -
@echo Steps are:
@echo   Step 0: Clean up any old deployments (more for testing).
@echo   Step 1: Code the service (prepared in advance).
@echo   Step 2: Compile the service and prepare it for use.
@echo   Step 3: Code the clients  (prepared in advance).
@echo   Step 4: Compile the clients.
@echo   Step 5: Test everything out.
@echo -
@echo ------------------------------------------------------------------------
@echo -
@echo Step 0: clean up any old deployments
erase /q helpers
erase /q classes
erase /q service-config.wsdd
@echo -
call :pause %*
@echo ------------------------------------------------------------------------
@echo -
@echo Step 1: code the service
@echo    We have prepared step1 in advance, see StockQuoteAxis.java and SecondAxis.java
dir /b *.java
@echo -
call :pause %*
@
@echo -
@echo ------------------------------------------------------------------------
@echo -
@echo Step 2: compile the service and prepare it for use.
@echo    This invokes deployWMQService.bat, which in turn does many things, as ...
call ..\..\bin\deployWMQService -?
@echo -
@echo    We will now call deployWMQService for each Java service.
@echo -
call :pause %*
@echo    First call with no package, Axis will use DefaultNamespace for all proxies etc
call ..\..\bin\deployWMQService -m MQSOAP.DEMO.QM StockQuoteAxis.java 
@echo -
@echo    Second call with explicit package, use class notation so we need to warn that it is Axis
call ..\..\bin\deployWMQService -m MQSOAP.DEMO.QM -c allAxis secondPackage.SecondAxis 
@echo -
@echo Deployment and preparation now complete.
call :pause %*
@
@echo -
@echo ------------------------------------------------------------------------
@echo -
@echo Step 3: code the clients
@echo    We have prepared step3 in advance, in the testClient subdirectory
dir /b testClient
@echo -
call :pause %*
@
@echo -
@echo ------------------------------------------------------------------------
@echo -
@echo Step 4: compile the clients.
@echo   buildClients.bat demonstrates this.
@echo   Note that buildClients picks up the appropriate generated proxies 
@echo   from the preparation step2.
pushd testClient
call buildClients
popd
@echo -
@echo Clients now built.
@echo Deployment complete, now ready to start execution
@echo -
call :pause %*
@
@echo -
@echo ------------------------------------------------------------------------
@echo -
@echo Step 5: test everything out
@echo    This will start a trigger monitor, which will in turn start listeners/servers as needed.
@echo    It will then run one of the test clients.
@echo -
@echo -
call :pause %*
@echo -
@echo    Start a WMQ trigger monitor, that will ensure the listeners start as needed.
call ..\..\bin\deployWMQService -m MQSOAP.DEMO.QM -c startWMQMonitor secondPackage.SecondAxis 
@echo -
@echo    Start a Java client
call testClient\StockQuoteAxisClientJava
@echo -
@echo    Start a C# client
testClient\StockQuoteAxisClientCS
@echo -
@echo ------------------------------------------------------------------------
@echo -
@echo    Deployment and Test now complete
@echo -
@echo ------------------------------------------------------------------------
@echo -
call :pause %*
exit /b

:pause
@if not "%1"=="nopause" pause
@exit /b

